#version 130

//Shader by LoLip_p

#include "/settings.glsl"

in vec2 TexCoords;
uniform sampler2D colortex0;

#if FOG == 1
uniform sampler2D depthtex0;
uniform int isEyeInWater;
uniform float near, far;
uniform float blindness;
uniform float darknessFactor;
uniform vec3 fogColor;
uniform mat4 gbufferProjectionInverse;

vec3 projectAndDivide(mat4 projectionMatrix, vec3 position){
	vec4 homPos = projectionMatrix * vec4(position, 1.0);
	return homPos.xyz / homPos.w;
}
#endif

void main() {
    vec3 color = texture2D(colortex0, TexCoords).rgb;
	
	#if FOG == 1
	float depth0 = texture2D(depthtex0, TexCoords).r;
	
	if(depth0 == 1) {
		/*DRAWBUFFERS:0*/
		gl_FragData[0] = vec4(pow(color, vec3(0.45)), 1.0f);
		return;
	}
	
	vec3 NDCPos = vec3(TexCoords.xy, depth0) * 2.0 - 1.0;
	vec3 viewPos = projectAndDivide(gbufferProjectionInverse, NDCPos);
	
	float farW = far;
	float distW = FOG_DISTANCE;
	
	if(isEyeInWater == 1) {
		farW = 64;
		distW = 5;
	}
	
	float distance = length(viewPos) / (farW * mix(mix(1, near * 0.5, blindness), near, darknessFactor));
	float fogFactor = exp(-mix(distW, 1, blindness) * (1.0 - distance));
	
	color = mix(color, pow(fogColor, vec3(2.2f)), clamp(fogFactor, 0.0, 1.0));
	#endif
	
	color = pow(color, vec3(0.45));
	
    // Apply saturation, brightness, and contrast
    float average = (color.r + color.g + color.b) / 3.0;
    color.rgb = mix(vec3(average), color.rgb, SATURATION);
    color.rgb += BRIGHTNESS;
    color.rgb = ((color.rgb - 0.5) * CONTRAST) + 0.5;

    gl_FragColor = vec4(color, 1.0);
}
